@@ -145,6 +145,10 @@ const char *iftype_name(enum nl80211_iftype iftype)
 }
 
 static const char *commands[NL80211_CMD_MAX + 1] = {
+/*
+ * sed 's/^\tNL80211_CMD_//;t n;d;:n s%^\([^=]*\),.*%\t[NL80211_CMD_\1] = \"\L\1\",%;t;d' nl80211.h
+ */
+	[NL80211_CMD_UNSPEC] = "unspec",
 	[NL80211_CMD_GET_WIPHY] = "get_wiphy",
 	[NL80211_CMD_SET_WIPHY] = "set_wiphy",
 	[NL80211_CMD_NEW_WIPHY] = "new_wiphy",
@@ -159,8 +163,8 @@ static const char *commands[NL80211_CMD_MAX + 1] = {
 	[NL80211_CMD_DEL_KEY] = "del_key",
 	[NL80211_CMD_GET_BEACON] = "get_beacon",
 	[NL80211_CMD_SET_BEACON] = "set_beacon",
-	[NL80211_CMD_NEW_BEACON] = "new_beacon",
-	[NL80211_CMD_DEL_BEACON] = "del_beacon",
+	[NL80211_CMD_START_AP] = "start_ap",
+	[NL80211_CMD_STOP_AP] = "stop_ap",
 	[NL80211_CMD_GET_STATION] = "get_station",
 	[NL80211_CMD_SET_STATION] = "set_station",
 	[NL80211_CMD_NEW_STATION] = "new_station",
@@ -171,10 +175,9 @@ static const char *commands[NL80211_CMD_MAX + 1] = {
 	[NL80211_CMD_DEL_MPATH] = "del_mpath",
 	[NL80211_CMD_SET_BSS] = "set_bss",
 	[NL80211_CMD_SET_REG] = "set_reg",
-	[NL80211_CMD_REQ_SET_REG] = "reg_set_reg",
-	[NL80211_CMD_GET_MESH_PARAMS] = "get_mesh_params",
-	[NL80211_CMD_SET_MESH_PARAMS] = "set_mesh_params",
-	[NL80211_CMD_SET_MGMT_EXTRA_IE] = "set_mgmt_extra_ie",
+	[NL80211_CMD_REQ_SET_REG] = "req_set_reg",
+	[NL80211_CMD_GET_MESH_CONFIG] = "get_mesh_config",
+	[NL80211_CMD_SET_MESH_CONFIG] = "set_mesh_config",
 	[NL80211_CMD_GET_REG] = "get_reg",
 	[NL80211_CMD_GET_SCAN] = "get_scan",
 	[NL80211_CMD_TRIGGER_SCAN] = "trigger_scan",
@@ -195,20 +198,44 @@ static const char *commands[NL80211_CMD_MAX + 1] = {
 	[NL80211_CMD_DISCONNECT] = "disconnect",
 	[NL80211_CMD_SET_WIPHY_NETNS] = "set_wiphy_netns",
 	[NL80211_CMD_GET_SURVEY] = "get_survey",
+	[NL80211_CMD_NEW_SURVEY_RESULTS] = "new_survey_results",
 	[NL80211_CMD_SET_PMKSA] = "set_pmksa",
 	[NL80211_CMD_DEL_PMKSA] = "del_pmksa",
 	[NL80211_CMD_FLUSH_PMKSA] = "flush_pmksa",
 	[NL80211_CMD_REMAIN_ON_CHANNEL] = "remain_on_channel",
 	[NL80211_CMD_CANCEL_REMAIN_ON_CHANNEL] = "cancel_remain_on_channel",
 	[NL80211_CMD_SET_TX_BITRATE_MASK] = "set_tx_bitrate_mask",
-	[NL80211_CMD_REGISTER_ACTION] = "register_action",
-	[NL80211_CMD_ACTION] = "action",
+	[NL80211_CMD_REGISTER_FRAME] = "register_frame",
+	[NL80211_CMD_FRAME] = "frame",
+	[NL80211_CMD_FRAME_TX_STATUS] = "frame_tx_status",
+	[NL80211_CMD_SET_POWER_SAVE] = "set_power_save",
+	[NL80211_CMD_GET_POWER_SAVE] = "get_power_save",
+	[NL80211_CMD_SET_CQM] = "set_cqm",
+	[NL80211_CMD_NOTIFY_CQM] = "notify_cqm",
 	[NL80211_CMD_SET_CHANNEL] = "set_channel",
 	[NL80211_CMD_SET_WDS_PEER] = "set_wds_peer",
 	[NL80211_CMD_FRAME_WAIT_CANCEL] = "frame_wait_cancel",
 	[NL80211_CMD_JOIN_MESH] = "join_mesh",
 	[NL80211_CMD_LEAVE_MESH] = "leave_mesh",
+	[NL80211_CMD_UNPROT_DEAUTHENTICATE] = "unprot_deauthenticate",
+	[NL80211_CMD_UNPROT_DISASSOCIATE] = "unprot_disassociate",
+	[NL80211_CMD_NEW_PEER_CANDIDATE] = "new_peer_candidate",
+	[NL80211_CMD_GET_WOWLAN] = "get_wowlan",
+	[NL80211_CMD_SET_WOWLAN] = "set_wowlan",
+	[NL80211_CMD_START_SCHED_SCAN] = "start_sched_scan",
+	[NL80211_CMD_STOP_SCHED_SCAN] = "stop_sched_scan",
+	[NL80211_CMD_SCHED_SCAN_RESULTS] = "sched_scan_results",
+	[NL80211_CMD_SCHED_SCAN_STOPPED] = "sched_scan_stopped",
 	[NL80211_CMD_SET_REKEY_OFFLOAD] = "set_rekey_offload",
+	[NL80211_CMD_PMKSA_CANDIDATE] = "pmksa_candidate",
+	[NL80211_CMD_TDLS_OPER] = "tdls_oper",
+	[NL80211_CMD_TDLS_MGMT] = "tdls_mgmt",
+	[NL80211_CMD_UNEXPECTED_FRAME] = "unexpected_frame",
+	[NL80211_CMD_PROBE_CLIENT] = "probe_client",
+	[NL80211_CMD_REGISTER_BEACONS] = "register_beacons",
+	[NL80211_CMD_UNEXPECTED_4ADDR_FRAME] = "unexpected_4addr_frame",
+	[NL80211_CMD_SET_NOACK_MAP] = "set_noack_map",
+	[NL80211_CMD_CH_SWITCH_NOTIFY] = "ch_switch_notify",
 };
 
 static char cmdbuf[100];
